package App::freq ;  
our $VERSION = '0.124' ; 
our $DATE = '2024-03-15T09:37+09:00' ; 

=encoding utf8

=head1 NAME

App::freq The command `freq' counts how many different content of each line appears, with various options.

=head1 SYNOPSIS

This module provides a Unix-like command `F<freq>'. 
The function is similar to `sort | uniq -c' also with many useful functions.

=head1 DESCRIPTION

=head1 SEE ALSO

=cut

1 ;
